package com.ruoyi.business.service.impl;

import java.util.List;

import com.ruoyi.business.domain.TConveyorStatus;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.business.mapper.TConveyorStatusMapper;
import com.ruoyi.business.service.ITConveyorStatusService;
import com.ruoyi.common.core.text.Convert;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;

/**
 * 【请填写功能名称】Service业务层处理
 * 
 * @author wms
 * @date 2022-06-11
 */
@Service
public class TConveyorStatusServiceImpl extends ServiceImpl<TConveyorStatusMapper, TConveyorStatus> implements ITConveyorStatusService
{
    @Autowired
    private TConveyorStatusMapper tConveyorStatusMapper;

    /**
     * 查询【请填写功能名称】
     * 
     * @param converyorId 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    @Override
    public TConveyorStatus selectTConveyorStatusByConveryorId(String converyorId)
    {
        return tConveyorStatusMapper.selectTConveyorStatusByConveryorId(converyorId);
    }

    /**
     * 查询【请填写功能名称】列表
     * 
     * @param tConveyorStatus 【请填写功能名称】
     * @return 【请填写功能名称】
     */
    @Override
    public List<TConveyorStatus> selectTConveyorStatusList(TConveyorStatus tConveyorStatus)
    {
        return tConveyorStatusMapper.selectTConveyorStatusList(tConveyorStatus);
    }

    /**
     * 新增【请填写功能名称】
     * 
     * @param tConveyorStatus 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int insertTConveyorStatus(TConveyorStatus tConveyorStatus)
    {
        return tConveyorStatusMapper.insertTConveyorStatus(tConveyorStatus);
    }

    /**
     * 修改【请填写功能名称】
     * 
     * @param tConveyorStatus 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int updateTConveyorStatus(TConveyorStatus tConveyorStatus)
    {
        return tConveyorStatusMapper.updateTConveyorStatus(tConveyorStatus);
    }

    /**
     * 批量删除【请填写功能名称】
     * 
     * @param converyorIds 需要删除的【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteTConveyorStatusByConveryorIds(String converyorIds)
    {
        return tConveyorStatusMapper.deleteTConveyorStatusByConveryorIds(Convert.toStrArray(converyorIds));
    }

    /**
     * 删除【请填写功能名称】信息
     * 
     * @param converyorId 【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteTConveyorStatusByConveryorId(String converyorId)
    {
        return tConveyorStatusMapper.deleteTConveyorStatusByConveryorId(converyorId);
    }
}
