package com.ruoyi.web.controller.business;

import java.util.List;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.business.domain.TConveyorStatus;
import com.ruoyi.business.service.ITConveyorStatusService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 【请填写功能名称】Controller
 * 
 * @author wms
 * @date 2022-06-11
 */
@Controller
@RequestMapping("/business/status")
public class TConveyorStatusController extends BaseController
{
    private String prefix = "business/status";

    @Autowired
    private ITConveyorStatusService tConveyorStatusService;

    @RequiresPermissions("business:status:view")
    @GetMapping()
    public String status()
    {
        return prefix + "/status";
    }

    /**
     * 查询【请填写功能名称】列表
     */
    @RequiresPermissions("business:status:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TConveyorStatus tConveyorStatus)
    {
        startPage();
        List<TConveyorStatus> list = tConveyorStatusService.selectTConveyorStatusList(tConveyorStatus);
        return getDataTable(list);
    }

    /**
     * 导出【请填写功能名称】列表
     */
    @RequiresPermissions("business:status:export")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TConveyorStatus tConveyorStatus)
    {
        List<TConveyorStatus> list = tConveyorStatusService.selectTConveyorStatusList(tConveyorStatus);
        ExcelUtil<TConveyorStatus> util = new ExcelUtil<TConveyorStatus>(TConveyorStatus.class);
        return util.exportExcel(list, "【请填写功能名称】数据");
    }

    /**
     * 新增【请填写功能名称】
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存【请填写功能名称】
     */
    @RequiresPermissions("business:status:add")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TConveyorStatus tConveyorStatus)
    {
        return toAjax(tConveyorStatusService.insertTConveyorStatus(tConveyorStatus));
    }

    /**
     * 修改【请填写功能名称】
     */
    @RequiresPermissions("business:status:edit")
    @GetMapping("/edit/{converyorId}")
    public String edit(@PathVariable("converyorId") String converyorId, ModelMap mmap)
    {
        TConveyorStatus tConveyorStatus = tConveyorStatusService.selectTConveyorStatusByConveryorId(converyorId);
        mmap.put("tConveyorStatus", tConveyorStatus);
        return prefix + "/edit";
    }

    /**
     * 修改保存【请填写功能名称】
     */
    @RequiresPermissions("business:status:edit")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TConveyorStatus tConveyorStatus)
    {
        return toAjax(tConveyorStatusService.updateTConveyorStatus(tConveyorStatus));
    }

    /**
     * 删除【请填写功能名称】
     */
    @RequiresPermissions("business:status:remove")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(tConveyorStatusService.deleteTConveyorStatusByConveryorIds(ids));
    }
}
